#include <stdlib.h>
#include <iostream>

#include <cmath>
#include <complex>
#include <iostream>

#include <boost/typeof/std/complex.hpp>
#include <boost/units/config.hpp>

#include <boost/units/cmath.hpp>
#include <boost/units/io.hpp>
#include <boost/units/systems/si.hpp>
#include <boost/units/systems/si/base.hpp>
#include <boost/units/systems/si/codata/physico-chemical_constants.hpp>
#include <boost/units/systems/si/io.hpp>
#include <boost/units/systems/si/prefixes.hpp>
#include <boost/units/systems/si/codata_constants.hpp>
#include <boost/units/systems/si/codata/electron_constants.hpp>
#include <boost/units/systems/si/codata/neutron_constants.hpp>
#include <boost/units/systems/si/codata/proton_constants.hpp>

//#include "measurement.hpp"

namespace boost {

    namespace units {

        namespace si {

            /*
            typedef make_dimension_list<
                boost::mpl::list< dim< length_base_dimension,static_rational<3> >,
                                  dim< mass_base_dimension,static_rational<1> >,
                                  dim< time_base_dimension,static_rational<-2> >,
                                  dim< current_base_dimension,static_rational<-2> > >
                                  >::type    coulomb_constant_dimension;
             */
            typedef derived_dimension<
            length_base_dimension, 3,
            mass_base_dimension, 1,
            time_base_dimension, -2,
            electric_charge_base_dimension, -2 > ::type coulomb_constant_dimension;
            typedef unit<coulomb_constant_dimension, si::system> ccu;

            BOOST_UNITS_STATIC_CONSTANT(mitch, ccu);
            BOOST_UNITS_PHYSICAL_CONSTANT(CoulombsConstant, quantity<ccu>, 8.987551787368173e+9 * mitch, 4.0e-12 * mitch);
        }
    }
}
using namespace std;

int main(int argc, char** argv) {
    using namespace boost::units;
    using namespace boost::units::si;
    using namespace boost::units::si::constants;
    using namespace boost::units::si::constants::codata;



    //	typedef make_scaled_unit<si::time, scale<10, static_rational<nano> >::type nanosecond;
    //	typedef make_scaled_unit<si::length, scale<10, static_rational<si::milli> >::type millimeters;

    force uforce = newton;
    energy uenergy = joule;
    length ulength = meter;
    velocity uvelocity = meters / second;
    quantity<length> sphereRadius(65.0 * milli * ulength);
    quantity<length> maxIonRadius(130.0 * milli * ulength);
    quantity<length> stepSizeLength(0.1 * milli * ulength);
    quantity<force> forceResult(1.0 * newton);
    quantity<electric_charge> oneCoulomb(1.0 * coulomb);
    quantity<length> oneMeter(1.0 * meter);
    quantity<mass> onekilogram(1.0 * kilogram);
    quantity<acceleration> accelerationResult(1.0 * meter_per_second_squared);

    forceResult = (boost::units::si::CoulombsConstant * oneCoulomb * oneCoulomb)/(oneMeter * oneMeter);
    std::cout << "testresult: " << forceResult << "\n";

    forceResult = (boost::units::si::CoulombsConstant * e * oneCoulomb)/(oneMeter * oneMeter);
    accelerationResult = forceResult / m_e;
    std::cout << "forceresult: " << forceResult << "\n";
    std::cout << "accelerationResult: " << accelerationResult << "\n";

    return 0;
}
